@@ -1,5 +1,5 @@
 package Crypt::Passphrase::PassphraseHash;
-$Crypt::Passphrase::PassphraseHash::VERSION = '0.019';
+$Crypt::Passphrase::PassphraseHash::VERSION = '0.020';
 use strict;
 use warnings;
 
@@ -43,7 +43,7 @@ Crypt::Passphrase::PassphraseHash - An object representing a hash for password c
 
 =head1 VERSION
 
-version 0.019
+version 0.020
 
 =head1 DESCRIPTION
 
@@ -55,7 +55,7 @@ This class can be useful for plugging C<Crypt::Passphrase> into some frameworks
 
  Crypt::Passphrase::PassphraseHash->new($crypt_passphrase, $raw_hash)
 
-This takes a C<Crypt::Passphrase> object, and a hash string. You probably want to use the C<curry_with_hash> or C<curry_with_password> methods on C<Crypt::Passphrase> instead of calling this directly. Typically called by C<< Crypt::Passphrase->curry_with_hash($hash) >> instead of directly.
+This takes a C<Crypt::Passphrase> object, and a hash string. You probably want to use the C<curry_with_hash> method on C<Crypt::Passphrase> instead of calling this directly, e,g, C<< Crypt::Passphrase->curry_with_hash($hash) >>.
 
 =head2 verify_password
 
